clear all
clc
%
%
%		File contenente i dati iniziali del progetto: momenti d'inerzia,
%		dimensioni geometriche, coppie applicate, velocit angolari iniziali,
%		angoli di Eulero iniziali
%		Da migliorare con un men nel quale si possano cambiare i parametri
%
%		Si assume inizialmente u,v,w allineati come x,y,z, assi rispettivamente 
%		di yaw, roll e pitch. 
%
%		Fase di missione nominale: il satellite si muove spinnato attorno 
%		all'asse di minima inerzia che corssisponde a quello di pitch. (1980)
%
%
msgbox('Fine caricamento dati iniziali');
%
%
%		CARATTERISTICHE INERZIALI
%
%
global Iu;
global Iv;
global Iw;
Iu=1022.8225;								% [Kg*m2]
Iv=1022.8225;								% [Kg*m2]
Iw=229.16;									% [Kg*m2]
%
%
%		CARATTERISTICHE GEOMETRICHE
%
%
global rsc;
global hcs;
		rsc=0.6;								% [m]		raggio geometrico del satellite
		hsc=3.7;								% [m]		altezza geometrica del satellite
global xc;									% [m]
global yc;									% [m]
global zc;									% [m]
		[xc,yc,zc]=cylinder(rsc,100);	%			(il satellite ha forma cilindrica con pannelli solari sulla faccia laterale del cilindro)
global d;
		d=0.05;								% [m]		spostamento del baricentro per avere M_sol
%
%
xc=xc-(xc./2);
yc=yc-(yc./2);
zc=hsc.*zc;
zc=zc-(((hsc+d)/2)*ones(size(zc)));
axis_xc=rsc;
axis_yc=rsc;
axis_zc=hsc;
%
%
%		MOTO LIBERO
%
%
Mu0=0;										% [N*m]
Mv0=0;										% [N*m]
Mw0=0;										% [N*m]
Wu0=0.1;										% [rad/s]
Wv0=0.1;										% [rad/s]
Ww0=0.2;										% [rad/s]
%
%
%
%		ORBITA GTO
%
%
K=398199;                           % [Km3/s2]
Rp=6878;                            % [Km]     il raggio al perigeo
Ra=42220;                           % [Km]     il raggio all'apogeo: immissione GEO
a=(Ra+Rp)/2;                        % [Km]     il semiasse maggiore
Vp=sqrt(K*(2/Rp-1/a));					% [Km/s]   la vel iniziale
Ts=sqrt((4*pi^2/K)*(a)^3); 			% [s]      il tempo di trasferimento
%
%
x0=Rp;										% [km]
y0=0;											% [km]
z0=0;											% [km]
%
%
Vx0=0;										% [Km/s]
Vy0=Vp;										% [Km/s]
Vz0=0;										% [Km/s]
%
%
phi0=0.*pi/180;							% [rad]
theta0=0.*pi/180;							% [rad]
psi0=0.*pi/180;							% [rad]
%
%
TSIM=Ts; 									% [s]			tempo di simulazione
alfag0=0;   								% [rad] 		ascensione retta di Greenwich
%
%
%		ATTUATORI
%
%
global Ir;
Ir=0.143;                        	% [Kg m2] 
WRw0=350;									% [rad/s]


