function M_sol=RadSol(u)
%
%
%		Calcola la coppia dovuta alla pressione di radiazione solare. Si considera il sistema Terra - Sole all'equinozio
%		di primavera e l'asse maggiore dell'orbita del satellite ortogonale alla congiungente Terra - Sole; l'asse Y e' diretto
%		verso il punto Vernale mentre l'asse x e' diretto nella direzione estate_inverno. Il sole poi "si sposta" di 1 deg/giorno.
%		Si confonde la congiungente Terra - Sole con quella satellite - Sole.
%  
%		phi, theta e psi sono gli angoli di Eulero per una parametrizzazione 231.
%		xCG, yCG e zCG sono le coordinate del satellite nel sistema terrestre, mentre t e' il tempo trascorso dall'equinozio di primavera.
%
%
u_cg=u(1);									% [Km]
v_cg=u(2);                     		% [Km]
w_cg=u(3);                     		% [Km]
phi=u(4);                   			% [rad]
theta=u(5);                 			% [rad]
psi=u(6);                   			% [rad]
time=fix(u(7)/(24*60*60));  			% [giorni trascorsi]
%
%
global incsole;
global Rfot;
global Rter;
global c;
global Fe0;
global cs;
global cd;
global A1;
global A2;
global d;
global rsc;
global hcs;
		rsc=0.6;                      % [m]			raggio geometrico del satellite
		hsc=3.7;								% [m]			altezza geometrica del satellite
%
%
Rfot=6.9599e5;								% [Km]		raggio della fotosfera
Rter=6371.2;								% [Km]		raggio medio terrestre
c=2.99792458e8;							% [m/s]		velocita' della luce
Fe0=1.05*(1358/(1.0004-0.0334));		% [Watt/m2]	costante solare al perielio
cs=0.3;										% 				coefficiente di riflessione speculare
cd=0.1;										% 				coefficiente di riflessione diffusa
A1=2*rsc.*hsc.*pi;						% [m2]		area laterale del satellite
A2=pi.*(rsc.^2);							% [m2]		area della base del satellite
d=0.05;										% [m]			spostamento del baricentro per avere M_sol
%
%
w=[0;0;1];									% 				asse w locale
%
%
%		SDR ECLITTICA ---> ASSI TERRESTRI ---> ASSI LOCALI
%
%
%		Le coppie dovute alla radiazione solare vengono calcolate nel sistema degli assi locali. Pertanto si
%		lascia inalterato w=[0;0;1], mentre si deve ruotare il vettore Terra - Sole.
%		Si ricordi che gli assi terrestri sono stati definiti: X nel piano orbitale diretto come la radiale,
%		Y nel piano orbitale diretto opposto al punto d'Ariete, Z perperndicolare al piano orbitale e destrorso;
%		ne consegue che il vettore TS verra' inizialmente calcolato nel piano dell'eclittica, ruotato nel piano
%		equatoriale terrestre, ruotato in assi terrestri tenendo conto sia dell'inclinazione dell'orbita
%		sull'equatore terrestre sia dell'ascensione retta del nodo ascendente
%
%
angle=(pi/180).*time;					% [rad]
%
%
TSecl=[-sin(angle);-cos(angle);0];	% 				versore Terra - Sole nel piano dell'eclittica
incsole=-23.4392911*(pi/180);			% [rad]
i_orb=(pi/180).*98.82;					% [rad]		inclinazione del piano dell'orbita rispetto al piano terrestre equatoriale
asc_orb=(pi/180).*9.29;					% [rad]		ascensione retta del nodo ascendente rispetto al punto di Ariete
%
%
Ai=[cos(incsole+i_orb) 0 -sin(incsole+i_orb);
 							0 1 0;
  	 sin(incsole+i_orb) 0 cos(incsole+i_orb)];
%
%
Aasc=[1 			0 				0;
		0 cos(asc_orb) sin(asc_orb);
		0 -sin(asc_orb) cos(asc_orb)];
%
%
Axyz_uvw=zeros(3,3);
Axyz_uvw(1,1)=cos(psi).*cos(theta);
Axyz_uvw(2,1)=-sin(theta);
Axyz_uvw(3,1)=sin(psi).*cos(theta);
Axyz_uvw(1,2)=cos(psi).*sin(theta).*cos(phi)+sin(psi).*sin(phi);
Axyz_uvw(2,2)=cos(theta).*cos(phi);
Axyz_uvw(3,2)=sin(theta).*sin(psi).*cos(phi)-cos(psi).*sin(phi);
Axyz_uvw(1,3)=cos(psi).*sin(theta).*sin(phi)-cos(phi).*sin(psi);
Axyz_uvw(2,3)=cos(theta).*sin(phi);
Axyz_uvw(3,3)=sin(psi).*sin(theta).*sin(phi)+cos(psi).*cos(phi);
%
%
versTSorb=(Axyz_uvw)*Aasc*Ai*TSecl;	% 				questo e' proprio il passaggio per portare TSecl negli assi locali
vettTSorb=1.495978e8.*versTSorb;		%				vettore Terra - Sole tenendo conto del modulo della distanza (1 U.A.) in Km
dp=[-u_cg;-v_cg;-w_cg];					% [Km]		vettore sat - Terra
ros=asin(Rfot./norm(vettTSorb));		% [rad]		raggio angolare del Sole
rop=asin(Rter./norm(dp));				% [rad]		raggio angolare della Terra
th=acos((versTSorb'*dp)/(norm(dp)));% [rad]		angolo di separazione apparente Sole - Terra
												%				calcolato partendo dalla formula a(vett) scalare b(vett)=a*b*cos(th)
%
%
global z1;                          %           parte deputata alla possibile eclisse. Nella simulazione si  impostato 
global z2;                          %           l'orologio in modo che l'eclisse non si verifichi.
z1=rop-ros;									%				possono essere richiamate a fine simulazione in Matlab
z2=th;										%				per verificare se avviene l'eclisse
%
%
%		CALCOLO DELLA RADIAZIONE SOLARE NEL SISTEMA LOCALE
%
%
if (rop-ros)>th							% 				condizione di eclisse totale
   Fe=0;										% [Watt/m2]
else											% 				condizione di luce
   Fe=Fe0;									% [Watt/m2]
end
%
%
p=Fe/c;										% [N/m2]
alfaw=acos(versTSorb'*w);				% [rad]		angolo fra asse di beccheggio (asse di simmetria geometrica del satellite) e direzione 
												%				sat - Sole calcolato partendo dalla formula a(vett) scalare b(vett)=a*b*cos(th)
%
%
Fsol_uvw=-p.*(((sin(alfaw).*(1+(1/3).*cs)+(pi/6).*cd).*A1+(1-cs).*cos(alfaw).*A2).*versTSorb...
   		+((-(4/3).*cs.*sin(alfaw)-(pi/6).*cd).*cos(alfaw).*A1...
		   +2.*(cs.*cos(alfaw)+(1/3).*cd).*cos(alfaw).*A2).*w);			% [N]
%
%
% Il centro di massa e' rispetto al centro geometrico rp=[0;0;d], da cui
%
%
M_sol=[Fsol_uvw(2).*d;-Fsol_uvw(1).*d;0;z1;z2];      % [N m]


